@@ -11,10 +11,14 @@ wich search engine you want to use using the ``search-engine`` setting.
 
 """
 import papis
-import os
-import sys
 import papis.utils
 import papis.config
+from papis.api import status
+
+
+def run(document):
+    papis.document.open_in_browser(document)
+    return status.success
 
 
 class Command(papis.commands.Command):
@@ -28,10 +32,8 @@ class Command(papis.commands.Command):
         self.add_search_argument()
 
     def main(self):
-        documents = papis.api.get_documents_in_lib(
-            self.get_args().lib,
-            self.get_args().search
-        )
+        documents = self.get_db().query(self.args.search)
         document = self.pick(documents)
-        if not document: return 0
-        papis.document.open_in_browser(document)
+        if not document:
+            return status.file_not_found
+        return run(document)
