@@ -19,7 +19,7 @@ CTRL_W = 23
 KEYS_ENTER = [curses.KEY_ENTER, ord('\n'), ord('\r')]
 KEYS_UP = [curses.KEY_UP, CTRL_P]
 KEYS_DOWN = [curses.KEY_DOWN, CTRL_N]
-KEYS_ERASE = [curses.KEY_BACKSPACE, CTRL_H]
+KEYS_ERASE = [curses.KEY_BACKSPACE, CTRL_H, 127]
 KEYS_QUIT = (CTRL_C, curses.KEY_EXIT, 27)
 KEYS_HALF_DOWN = [CTRL_D]
 KEYS_HALF_UP = [CTRL_U]
